import Taro from "@tarojs/taro";

// https://lbs.qq.com/service/webService/webServiceGuide/webServiceGcoder
// location 为 gcj02 编码
export function geocoder(location, getPoi = 0) {
  console.log('----待解析地址----', location)
  if (!location || location.length < 3) {
    return Promise.reject(new Error("待解析地址为空"));
  }

  return new Promise((resolve, reject) => {
    // eslint-disable-next-line no-undef
    const url = `${MAPHOST}/ws/geocoder/v1/?location=${location}&key=${QMAP_WEBSERVICE_KEY}&get_poi=${getPoi}`;

    Taro.request({ url })
      .then(({ data }) => {
        const { status, message, result } = data || {};
        if (status != 0) {
          console.error(data);
          reject(new Error(message));
        } else {
          resolve(result);
        }
      })
      .catch((err) => {
        console.error(err);
        reject(new Error(err.errMsg));
      });
  });
}

/**
 * 坐标系转换 - 转换为腾讯坐标系
 * https://lbs.qq.com/service/webService/webServiceGuide/webServiceTranslate
 * @param {*} lat 纬度
 * @param {*} lng 经度
 * @param {*} type , 1 GPS坐标, 2 sogou经纬度, 3 baidu经纬度, 4 mapbar经纬度, 6 sogou墨卡托
 */
export function translate(lat, lng, type = 3) {
  return new Promise((resolve, reject) => {
    const locs = `${lat},${lng}`

    // eslint-disable-next-line no-undef
    const url = `${MAPHOST}/ws/coord/v1/translate?locations=${locs}&type=${type}&key=${QMAP_WEBSERVICE_KEY}&output=json`;
    Taro.request({ url })
      .then(({ data }) => {
        const { status, message, locations } = data || {};
        if (status != 0) {
          console.error(data);
          reject(new Error(message));
        } else {
          // { lat, lng }
          resolve(locations[0]);
        }
      })
      .catch((err) => {
        console.error(err);
        reject(new Error(err.errMsg));
      });
  });
}