import Taro from "@tarojs/taro";
import { H5, TARO_ENV, getToken, setToken } from "./token";

import logger from "./log";

const getQueryStrByParams = (params) => {
  if (!params) return undefined;

  return Object.keys(params)
    .map((key) => {
      const value = params[key];
      return `${encodeURIComponent(key)}=${encodeURIComponent(value)}`;
    })
    .join("&");
};

export default function request(api, options = {}) {
  return new Promise((resolve, reject) => {
    const {
      method = "GET",
      params,
      data = {},
      header = {},
      silent = false,
      noSuccesTip,
      ...cfgs
    } = options;
    const queryStr = params ? getQueryStrByParams(params) : undefined;
    // eslint-disable-next-line no-undef
    const url = queryStr ? `${HOST}${api}?${queryStr}` : `${HOST}${api}`;
    const personId = Taro.getStorageSync("personId");
    const duty = Taro.getStorageSync("duty");

    const onError = (err) => {
      // console.error(err);
      // if (!H5) {
      //   console.log(1)
      //   logger.error(`接口 [${method}]: ${url}`);
      //   logger.error("参数: ", data);
      //   logger.error(err);
      // }

      if (!silent && "GET" !== method.toUpperCase()) {
        Taro.showModal({
          title: err.message || err,
          showCancel: false,
        });
      }

      reject(err);
    };

    Taro.request({
      url,
      data,
      method,
      header: {
        "x-client": "miniapp",
        "x-personId": personId,
        "x-duty": duty,
        "content-type": "application/json",
        authorization: getToken(),
        ...header,
      },
      ...cfgs,
    })
      .then(({ statusCode, header, data = result }) => {
        if (statusCode >= 300) {
          if (!H5) {
            logger.error(header);
          }
          return onError(`网络错误 ${statusCode}`);
        }

        if (data?.code === 1000) {
          if (data.data?.token) {
            setToken(data?.data?.token);
          }

          if (!silent && "GET" !== method.toUpperCase()) {
            if (!noSuccesTip) {
              Taro.showToast({
                title: "操作成功",
                icon: "none",
              });
            }
          }

          resolve(data.data);
        } else {
          onError(data);
        }
      })
      .catch(onError);
  });
}

export const uploadFiles = async (files, url) => {
  const uploads = [];
  const token = getToken();
  for (var i = 0; i < files.length; i++) {
    uploads[i] = new Promise((resolve, reject) => {
      const formData = new FormData();
      formData.append("file", files[i].originalFileObj);
      formData.append("fileType", files[i].fileType);

      // eslint-disable-next-line no-undef
      fetch(url || `${HOST}/api/ma/file`, {
        method: "POST",
        headers: { authorization: token },
        body: formData,
      })
        .then((res) => res.json()) // Add this line to parse the response as JSON
        .then((_data) => {
          if (_data.code !== 1000) {
            reject(new Error(_data.message));
          }

          resolve(_data.data);
        });
    });
  }

  return Promise.all(uploads);
};


export const uploadFileBase64 = async (base64, fileName, fileType) => {
  const uploads = [];
  const token = getToken();
  const formData = new FormData();
  formData.append("base64", base64);
  formData.append("fileName", fileName);
  formData.append("fileType", fileType);

  return new Promise((resolve, reject) => {
    // eslint-disable-next-line no-undef
    fetch(`${HOST}/api/ma/file/base64`, {
      method: "POST",
      headers: { authorization: token },
      body: formData,
    })
      .then((res) => res.json()) // Add this line to parse the response as JSON
      .then((_data) => {
        if (_data.code !== 1000) {
          reject(new Error(_data.message));
        }

        resolve(_data.data);
      });
  });
};
